.. finley documentation master file, created by
   sphinx-quickstart on Thu Feb  6 16:36:24 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to finley's documentation!
==================================

Contents:

.. toctree::
   :maxdepth: 2

   f_extract
   f_timeseries
   f_core
   f_tests


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

